#!/usr/bin/env python3
# coding=utf-8
#
# Copyright (C) 2016 Bas van den Broek
#

from __future__ import (absolute_import, division,
                        print_function, unicode_literals)

import logging
import sys

logger = logging.getLogger(__name__)


def main():
    pass


if __name__ == '__main__':
    sys.exit(main())
